@@ -34,6 +34,7 @@
 #include <telepathy-glib/interfaces.h>
 #include <telepathy-glib/util.h>
 
+#include <telepathy-logger/conf-internal.h>
 #include <telepathy-logger/entry.h>
 #include <telepathy-logger/entry-internal.h>
 #include <telepathy-logger/log-store-internal.h>
@@ -75,6 +76,8 @@
 
 typedef struct
 {
+  TplConf *conf;
+
   GList *stores;
   GList *writable_stores;
   GList *readable_stores;
@@ -120,6 +123,8 @@ log_manager_finalize (GObject *object)
 
   priv = TPL_LOG_MANAGER (object)->priv;
 
+  g_object_unref (priv->conf);
+
   g_list_foreach (priv->stores, (GFunc) g_object_unref, NULL);
   g_list_free (priv->stores);
   /* no unref needed here, the only reference kept is in priv->stores */
@@ -197,6 +202,15 @@ add_log_store (TplLogManager *self,
   return store;
 }
 
+static void
+_globally_enabled_changed (TplConf *conf,
+    GParamSpec *pspec,
+    gpointer user_data)
+{
+  DEBUG ("Logging has been globally %s",
+      _tpl_conf_is_globally_enabled (conf) ? "enabled" : "disabled");
+}
+
 static void
 tpl_log_manager_init (TplLogManager *self)
 {
@@ -208,6 +222,11 @@ tpl_log_manager_init (TplLogManager *self)
 
   DEBUG ("Initialising the Log Manager");
 
+  priv->conf = _tpl_conf_dup ();
+
+  g_signal_connect (priv->conf, "notify::globally-enabled",
+      G_CALLBACK (_globally_enabled_changed), NULL);
+
   /* The TPL's default read-write logstore */
   add_log_store (self, TPL_TYPE_LOG_STORE_XML, "TpLogger", TRUE, TRUE);
 
@@ -266,6 +285,12 @@ _tpl_log_manager_add_message (TplLogManager *manager,
 
   priv = manager->priv;
 
+  if (!_tpl_conf_is_globally_enabled (priv->conf))
+    {
+      /* ignore message, logging is globally disabled */
+      return FALSE;
+    }
+
   /* send the message to any writable log store */
   for (l = priv->writable_stores; l != NULL; l = g_list_next (l))
     {
@@ -714,6 +739,32 @@ _tpl_log_manager_search (TplLogManager *manager,
   return out;
 }
 
+TplLogSearchHit *
+_tpl_log_manager_search_hit_new (TpAccount *account,
+    const gchar *chat_id,
+    gboolean is_chatroom,
+    const gchar *filename,
+    GDate *date)
+{
+  TplLogSearchHit *hit = g_slice_new0 (TplLogSearchHit);
+
+  g_assert (chat_id != NULL);
+
+  if (account != NULL)
+    hit->account = g_object_ref (account);
+
+  hit->chat_id = g_strdup (chat_id);
+  hit->is_chatroom = is_chatroom;
+
+  if (filename != NULL)
+    hit->filename = g_strdup (filename);
+
+  if (date != NULL)
+    hit->date = g_date_new_dmy (g_date_get_day (date), g_date_get_month (date),
+        g_date_get_year (date));
+
+  return hit;
+}
 
 void
 _tpl_log_manager_search_hit_free (TplLogSearchHit *hit)
